sessions_schema = [
    'amount_subtotal',
    'amount_total',
    'cancel_url',
    'customer_address_city',
    'customer_address_country',
    'customer_address_postal_code',
    'customer_address_state',
    'customer_created',
    'customer_email',
    'customer_id',
    'customer_name',
    'subscriptions'
]

customer_schema = [
    'address_city',
    'address_country',
    'address_state',
    'created',
    'email',
    'id',
    'invoice_prefix',
    'livemode',
    'name',
    'subscriptions_data_billing_cycle_anchor',
    'subscriptions_data_cancel_at',
    'subscriptions_data_created',
    'subscriptions_data_current_period_end',
    'subscriptions_data_current_period_start',
    'subscriptions_data_customer',
    'subscriptions_data_default_payment_method',
    'subscriptions_data_id',
    'subscriptions_data_items_data_created',
    'subscriptions_data_items_data_id',
    'subscriptions_data_items_data_object',
    'subscriptions_data_items_data_plan_active',
    'subscriptions_data_items_data_plan_amount',
    'subscriptions_data_items_data_plan_amount',
    'subscriptions_data_items_data_plan_id',
    'subscriptions_data_items_data_plan_imnterval',
    'subscriptions_data_items_data_plan_interval_count',
    'subscriptions_data_items_data_plan_livemode',
    'subscriptions_data_items_data_plan_metadata_maxSpaceBytes',
    'subscriptions_data_items_data_plan_metadata_name',
    'subscriptions_data_items_data_plan_planType',
    'subscriptions_data_items_data_plan_product',
    'subscriptions_data_items_data_price_active',
    'subscriptions_data_items_data_price_id',
    'subscriptions_data_items_data_price_livemode',
    'subscriptions_data_items_data_price_metadata_maxSpaceBytes',
    'subscriptions_data_items_data_price_metadata_name',
    'subscriptions_data_items_data_price_metadata_planType',
    'subscriptions_data_items_data_price_product',
    'subscriptions_data_items_data_price_recurring_interval',
    'subscriptions_data_items_data_price_interval_count',
    'subscriptions_data_items_data_price_trial_period_days',
    'subscriptions_data_items_data_price_unit_amount',
    'subscriptions_data_items_data_price_type',
    'subscriptions_data_items_data_subscription',
    'subscriptions_latest_invoice',
    'subscriptions_data_discount_checkout_session',
    'subscriptions_data_discount_coupon_amount_off',
    'subscriptions_data_discount_coupon_duration',
    'subscriptions_data_discount_coupon_duration_in_months',
    'subscriptions_data_discount_coupon_name',
    'subscriptions_data_discount_coupon_percent_off',
    'subscriptions_data_discount_id',
    'subscriptions_data_discount_promotion_code',
]


charges_schema = [
    'amount',
    'amount_captured',
    'amount_refunded',
    'billing_details_address_city',
    'billing_details_address_country',
    'billing_details_email',
    'billing_details_name',
    'created',
    'customer',
    'currency',
    'description',
    'disputed',
    'id',
    'invoice_amount_due',
    'invoice_amount_paid',
    'invoice_billing_reason',
    'invoice_id',
    'invoice_lines_data_period_start',
    'invoice_lines_data_period_end',
    'invoice_lines_data_plan_active',
    'invoice_lines_data_plan_interval',
    'invoice_lines_data_plan_interval_count',
    'invoice_lines_data_plan_metadata_maxSpaceBytes',
    'invoice_lines_data_plan_metadata_name',
    'invoice_lines_data_plan_metadata_planType',
    'invoice_lines_data_plan_product',
    'invoice_lines_data_price_id',
    'invoice_lines_data_price_metadata_maxSpaceBytes,',
    'invoice_lines_data_price_metadata_name',
    'invoice_lines_data_price_planType',
    'invoice_lines_data_subscription',
    'livemode',
    'metadata_maxSpaceBytes',
    'metadata_name',
    'metadata_planType',
    'paid',
    'payment_intent',
    'payment_method',
    'payment_method_details_card_brand',
    'payment_method_details_card_country',
    'payment_method_details_card_exp_month',
    'payment_method_details_card_exp_year',
    'payment_intent_charges_data_metadata_lifetime_tier',
    'payment_intent_charges_data_metadata_maxSpaceBytes',
    'payment_intent_charges_data_metadata_name',
    'payment_intent_charges_data_metadata_planType',
    'receipt_email',
    'receipt_number',
    'receipt_url',
    'refunded',
    'status',
    'created',

    'metadata_lifetime_tier',
    'metadata_maxSpaceBytes',
    'metadata_name',
    'metadata_planType',


]
