charges_schema = [
    'amount',
    'amount_captured',
    'amount_refunded',
    'billing_details_address_city',
    'billing_details_address_country',
    'billing_details_email',
    'billing_details_name',
    'created',
    'customer',
    'currency',
    'description',
    'disputed',
    'id',
    'invoice_amount_due',
    'invoice_amount_paid',
    'invoice_billing_reason',
    'invoice_id',
    'invoice_lines_data_period_start',
    'invoice_lines_data_period_end',
    'invoice_lines_data_plan_active',
    'invoice_lines_data_plan_interval',
    'invoice_lines_data_plan_interval_count',
    'invoice_lines_data_plan_metadata_maxSpaceBytes',
    'invoice_lines_data_plan_metadata_name',
    'invoice_lines_data_plan_metadata_planType',
    'invoice_lines_data_plan_product',
    'invoice_lines_data_price_id',
    'invoice_lines_data_price_metadata_maxSpaceBytes,',
    'invoice_lines_data_price_metadata_name',
    'invoice_lines_data_price_planType',
    'invoice_lines_data_subscription',
    'livemode',
    'metadata_maxSpaceBytes',
    'metadata_name',
    'metadata_planType',
    'paid',
    'payment_intent',
    'payment_method',
    'payment_method_details_card_brand',
    'payment_method_details_card_country',
    'payment_method_details_card_exp_month',
    'payment_method_details_card_exp_year',
    'payment_intent_charges_data_metadata_lifetime_tier',
    'payment_intent_charges_data_metadata_maxSpaceBytes',
    'payment_intent_charges_data_metadata_name',
    'payment_intent_charges_data_metadata_planType',
    'receipt_email',
    'receipt_number',
    'receipt_url',
    'refunded',
    'status',
    'created',

    'metadata_lifetime_tier',
    'metadata_maxSpaceBytes',
    'metadata_name',
    'metadata_planType',


]
